==> magpie-data-0.7.1-sources.jar: io/openraven/magpie/data/aws/cloudwatch/CloudWatchLogGroup.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.cloudwatch;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.cloudwatchlogs.model.LogGroup;

import java.time.Instant;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = CloudWatchLogGroup.TABLE_NAME)
public class CloudWatchLogGroup  extends AWSResource {
  protected static final String TABLE_NAME = "awswatchloggroup";
  public static final String RESOURCE_TYPE = "AWS::CloudWatchLogs::LogGroup";

  public CloudWatchLogGroup() {
    this.resourceType = RESOURCE_TYPE;
  }

  public CloudWatchLogGroup(String accountId, String region, LogGroup logGroup) {

    this.resourceName = logGroup.logGroupName();
    this.arn = logGroup.arn();
    this.awsAccountId = accountId;
    this.awsRegion = region;
    this.resourceId = logGroup.arn();
    this.configuration = PayloadUtils.update(logGroup);
    this.createdIso = Instant.ofEpochMilli(logGroup.creationTime());
  }
}

==> magpie-data-0.11.2-sources.jar: io/openraven/magpie/data/aws/cloudwatch/CloudWatchLogGroup.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.cloudwatch;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.cloudwatchlogs.model.LogGroup;

import java.time.Instant;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = CloudWatchLogGroup.TABLE_NAME)
public class CloudWatchLogGroup  extends AWSResource {
  protected static final String TABLE_NAME = "awswatchloggroup";
  public static final String RESOURCE_TYPE = "AWS::CloudWatchLogs::LogGroup";

  public CloudWatchLogGroup() {
    this.resourceType = RESOURCE_TYPE;
  }

  public CloudWatchLogGroup(String accountId, String region, LogGroup logGroup) {

    this.resourceName = logGroup.logGroupName();
    this.arn = logGroup.arn();
    this.awsAccountId = accountId;
    this.awsRegion = region;
    this.resourceId = logGroup.arn();
    this.configuration = PayloadUtils.update(logGroup);
    this.createdIso = Instant.ofEpochMilli(logGroup.creationTime());
  }
}
